Description Usage Arguments Value Examples
Get table of absolute percent cover for given park and year
1 | get_pct_cover_tbl(cfg, park, year)
|
cfg |
NPS configuration list object; see |
park |
park abbreviation, eg "CABR", "CHIS" or "SAMO" |
year |
4-digit year |
Tibble that reproduces from mod_ExportQueries:
for "Figure E.2. Absolute foliar cover (%) of plant growth forms, as observed during 20XX monitoring at CABR. Colored bars show mean values, while error bars extend ±1 s.d. from the means." from MEDN_veg_protocol_NARRATIVE_FINAL_8Sep2016.pdf.
1 2 3 4 5 | cfg <- get_nps_config(system.file(package="npstools", "nps_config.yaml"))
park <- "CABR"
year <- 2015
get_pct_cover_tbl(cfg, park, year)
|
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.